# ct_manager


Database API Manager

<table>

<tr>
  <td>Latest Release</td>
  <td><img src="https://img.shields.io/pypi/v/ct_manager.svg" alt="latest release" /></td>
</tr>

<tr>
  <td>Python version</td>
  <td><img src="https://img.shields.io/badge/python-2.7-blue.svg"/>   <img src="https://img.shields.io/badge/python-3.5-blue.svg"/> <img src="https://img.shields.io/badge/python-3.6-blue.svg"/></td>
  </tr>

<tr>
  <td>Build Status</td>
  <td><img src="https://travis-ci.org/iLampard/ct_manager.svg?branch=master" alt="build status" /></td>
</tr>
</table>


* [项目概况](https://github.com/ilampard/ct_manager/blob/master/README.md#项目概况)

# 项目概况
*ct_manager* 提供了多种数据源的封装接口以及功能函数，使用方便，易扩展


*读取*


